@@ -35,6 +35,7 @@ __all__ = (
     "LoggingLevelType",
     "ReprocessingStatusType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -333,3 +334,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_channels", "list_dataset_contents", "list_datasets", "list_datastores", "list_pipelines"
+]
